<?php
namespace App\Factory;

use App\Exception\ParamsException as ParamsException;

class PaymentFactory {
    
    private $connection;
    private $util;
    
    public function __construct (\Doctrine\DBAL\Connection $connection,
                                 \App\Util\Util $util) {
        $this->connection = $connection;
        $this->util       = $util;
    }
    
    public function getPayments($subsidiaryCode, $cdCaixa , $nrSeqVenda){
        
        $sql = "
            SELECT MV.CDTIPORECE, MV.NRSEQUMOVI
                FROM MOVCAIXA MV
            WHERE MV.CDFILIAL = :CDFILIAL
              AND MV.CDCAIXA    = :CDCAIXA
              AND MV.NRSEQVENDA = :NRSEQVENDA
            ORDER BY NRSEQUMOVI
        ";
        
        $params = [
                ':CDFILIAL'   => $subsidiaryCode,
                ':CDCAIXA'    => $cdCaixa,
                ':NRSEQVENDA' => $nrSeqVenda
                ];
        
        $payments = $this->connection->fetchAll($sql, $params);
        
        return $payments;
    
    
    }
    
    public function getPaymentDetails($subsidiaryCode, $cdCaixa , $nrSeqVenda, $cdTipoRece, $nrSequMovi) {
        $sql = "
            SELECT MV.NRSEQVENDA, MV.CDTIPORECE, MV.NRSEQUMOVI, MV.IDTIPOMOVIVE, MV.VRMOVIVEND, MV.NRAUTORIZATEF, MV.CDNSUTEF, 
            MV.CDNSUHOSTTEF, TR.NMTIPORECE,TR.IDTIPORECE, TR.CDADMINCART, TR.CDBANCARTCR, TR.CDBANDEIRAINTE,
            TR.CDBANCARTSEFAZ, TR.CDCREDENCCAR, TR.CDOPERADORAINTE, RI.CDTPRECEINTE, CL.NMFANTCLIE
                FROM MOVCAIXA MV
                JOIN TIPORECE TR 
                    ON MV.CDTIPORECE = TR.CDTIPORECE
                LEFT JOIN (SELECT TP.CDTPRECEINTE, TP.CDTIPORECE    
                        FROM TIPORECEINTE TP
                            JOIN INTEGRACAO INTE
                                ON TP.CDINTEGRACAO = INTE.CDINTEGRACAO
                        WHERE INTE.IDINTEGRACAO = :IDINTEGRACAO
                            AND TP.CDTIPORECE = :CDTIPORECE) RI 
                    ON MV.CDTIPORECE = RI.CDTIPORECE
                LEFT JOIN CLIENTE CL
                    ON TR.CDCLIENTE = CL.CDCLIENTE
            WHERE MV.CDFILIAL = :CDFILIAL
            AND MV.CDCAIXA    = :CDCAIXA
            AND MV.NRSEQVENDA = :NRSEQVENDA
            AND MV.NRSEQUMOVI = :NRSEQUMOVI
            ORDER BY NRSEQUMOVI
            ";
        
        $params = [
            ':CDTIPORECE'   => $cdTipoRece,
            ':IDINTEGRACAO' => 'DTS',
            ':CDFILIAL'     => $subsidiaryCode,
            ':CDCAIXA'      => $cdCaixa,
            ':NRSEQVENDA'   => $nrSeqVenda,
            ':NRSEQUMOVI'   => $nrSequMovi
        ];
        
        $result = $this->connection->fetchAll($sql, $params);
        
        if(empty($result))
           return null; 
        
        return $result[0]; 
        
    }
    
}